@@ -25,6 +25,7 @@
 #include <KLocalizedString>
 
 // application specific includes
+#include "archiveman.h"
 #include "archdoc.h"
 #include "documentman.h"
 #include "kraftdb.h"
@@ -271,7 +272,7 @@ void ArchDoc::setSentOutDate( const QDateTime& dt )
     mAttributes.save(mArchDocID);
 }
 
-ArchDocDigest ArchDoc::toDigest()
+ArchDocDigest ArchDoc::toDigest() const
 {
     return ArchDocDigest(mPrintDate, mState, mIdent, mArchDocID);
 }
@@ -297,6 +298,15 @@ ArchDocDigest::~ArchDocDigest()
 
 }
 
+QString ArchDocDigest::pdfArchiveFileName() const
+{
+    const QString outputDir = ArchiveMan::self()->pdfBaseDir();
+    const QString filename = ArchiveMan::self()->archiveFileName(archDocIdent(),
+                                                           archDocId().toString(), "pdf" );
+    const QString file = QString( "%1/%2" ).arg( outputDir ).arg( filename );
+
+    return file;
+}
 
 /* ###################################################################### */
 
