@@ -41,15 +41,15 @@ public:
   /** Destructor for the fileclass of the application */
   ~ArchDocDigest();
 
-  QDateTime printDate() {
+  QDateTime printDate() const {
     return mPrintDate;
   }
 
-  int archDocState() {
+  int archDocState() const {
     return mState;
   }
 
-  dbID archDocId() {
+  dbID archDocId() const {
     return mArchDocId;
   }
 
@@ -57,6 +57,8 @@ public:
     return mIdent;
   }
 
+  QString pdfArchiveFileName() const;
+
 private:
   QDateTime mPrintDate;
   int       mState;
@@ -165,7 +167,7 @@ public:
   double tax() const;
   double reducedTax() const;
 
-  ArchDocDigest toDigest();
+  ArchDocDigest toDigest() const;
 
   // when the document was sent to the customer.
   QDateTime sentOutDate();
