@@ -32,6 +32,7 @@
 #include "dbids.h"
 #include "kraftsettings.h"
 #include "doctype.h"
+#include "defaultprovider.h"
 
 /* Table document:
  * +----------------+--------------+------+-----+-------------------+----------------+
@@ -58,6 +59,42 @@
  *
  */
 
+namespace {
+void checkAndSet(bool& changes, QSqlRecord& record, const QString& name, const QVariant& setValue)
+{
+    Q_ASSERT(record.contains(name)); // the record must have the column
+
+    if( record.value(name) != setValue) {
+        record.setValue(name, setValue);
+        changes = true;
+    }
+}
+
+
+bool fillDocumentBuffer(QSqlRecord &buf, KraftDoc *doc)
+{
+    bool changes {false};
+    if( doc ) {
+        checkAndSet(changes, buf, "ident", doc->ident());
+        checkAndSet(changes, buf, "docType", doc->docType());
+        checkAndSet(changes, buf, "docDescription", KraftDB::self()->mysqlEuroEncode(doc->whiteboard()));
+        checkAndSet(changes, buf, "clientID", doc->addressUid());
+        checkAndSet(changes, buf, "clientAddress", doc->address());
+        checkAndSet(changes, buf, "salut", doc->salut());
+        checkAndSet(changes, buf, "goodbye", doc->goodbye());
+        checkAndSet(changes, buf, "date", doc->date());
+        checkAndSet(changes, buf, "pretext", KraftDB::self()->mysqlEuroEncode( doc->preText()));
+        checkAndSet(changes, buf, "posttext", KraftDB::self()->mysqlEuroEncode( doc->postText()));
+        checkAndSet(changes, buf, "country", DefaultProvider::self()->locale()->bcp47Name());
+        checkAndSet(changes, buf, "language", "");
+        checkAndSet(changes, buf, "projectLabel", doc->projectLabel());
+        checkAndSet(changes, buf, "predecessor", doc->predecessor());
+
+    }
+    return changes;
+}
+}
+
 DocumentSaverDB::DocumentSaverDB( ) : DocumentSaverBase(),
                                       PosTypePosition( QString::fromLatin1( "Position" ) ),
                                       PosTypeExtraDiscount( QString::fromLatin1( "ExtraDiscount" ) ),
@@ -100,38 +137,42 @@ bool DocumentSaverDB::saveDocument(KraftDoc *doc )
         doc->setIdent( ident );
     }
 
-    fillDocumentBuffer( record, doc );
+    bool hasChanges = fillDocumentBuffer( record, doc );
 
     if( doc->isNew() ) {
-      // qDebug () << "Doc is new, inserting" << endl;
-      if( !model.insertRecord(-1, record)) {
-          QSqlError err = model.lastError();
-          // qDebug () << "################# SQL Error: " << err.text();
-      }
-      model.submitAll();
-
-      dbID id = KraftDB::self()->getLastInsertID();
-      doc->setDocID( id );
-
-      // get the uniq id and write it into the db
-      DocType dt( doc->docType() );
-      QString ident = dt.generateDocumentIdent( doc->date(), doc->docType(), doc->addressUid() );
-      doc->setIdent( ident );
-      model.setFilter("docID=" + id.toString());
-      model.select();
-      if ( model.rowCount() > 0 ) {
-        model.setData(model.index(0, 1), ident);
+        // qDebug () << "Doc is new, inserting" << endl;
+        if( !model.insertRecord(-1, record)) {
+            QSqlError err = model.lastError();
+            // qDebug () << "################# SQL Error: " << err.text();
+        }
         model.submitAll();
-      }
+
+        dbID id = KraftDB::self()->getLastInsertID();
+        doc->setDocID( id );
+
+        // get the uniq id and write it into the db
+        DocType dt( doc->docType() );
+        QString ident = dt.generateDocumentIdent( doc->date(), doc->docType(), doc->addressUid() );
+        doc->setIdent( ident );
+        model.setFilter("docID=" + id.toString());
+        model.select();
+        if ( model.rowCount() > 0 ) {
+            model.setData(model.index(0, 1), ident);
+            model.submitAll();
+        }
 
     } else {
-      // qDebug () << "Doc is not new, updating #" << doc->docID().intID() << endl;
-
-      record.setValue( "docID", doc->docID().toString() );
-
-      model.setRecord(0, record);
-      model.submitAll();
+        // qDebug () << "Doc is not new, updating #" << doc->docID().intID() << endl;
+        checkAndSet(hasChanges, record, "docID", doc->docID().toString());
+        if (!hasChanges) {
+            // if there haven't been changes in the document record, we update the changes
+            // timestamp manually, otherwise it is not updated at all.
+            const QString dt = QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
+            checkAndSet(hasChanges, record, "lastModified", QVariant(dt));
+        }
     }
+    model.setRecord(0, record);
+    model.submitAll();
 
     saveDocumentPositions( doc );
 
@@ -262,30 +303,6 @@ void DocumentSaverDB::saveDocumentPositions( KraftDoc *doc )
 
 }
 
-void DocumentSaverDB::fillDocumentBuffer( QSqlRecord &buf, KraftDoc *doc )
-{
-    if( doc ) {
-      // qDebug () << "Adressstring: " << doc->address() << endl;
-      buf.setValue( "ident",    doc->ident() );
-      buf.setValue( "docType",  doc->docType() );
-      buf.setValue( "docDescription", KraftDB::self()->mysqlEuroEncode( doc->whiteboard() ) );
-      buf.setValue( "clientID", doc->addressUid() );
-      buf.setValue( "clientAddress", doc->address() );
-      buf.setValue( "salut",    doc->salut() );
-      buf.setValue( "goodbye",  doc->goodbye() );
-      buf.setValue( "date",     doc->date() );
-      // do not set that because mysql automatically updates the timestamp and
-      // sqlite3 has a trigger for it.
-      // buf->setValue( "lastModified", "NOW()" );
-      buf.setValue( "pretext",  KraftDB::self()->mysqlEuroEncode( doc->preText() ) );
-      buf.setValue( "posttext", KraftDB::self()->mysqlEuroEncode( doc->postText() ) );
-      buf.setValue( "country",  doc->locale()->bcp47Name() );
-      buf.setValue( "language", "" );
-      buf.setValue( "projectLabel",  doc->projectLabel() );
-      buf.setValue( "predecessor", doc->predecessor() );
-    }
-}
-
 void DocumentSaverDB::load( const QString& id, KraftDoc *doc )
 {
     if( !id.isEmpty() ) {
@@ -301,7 +318,7 @@ void DocumentSaverDB::load( const QString& id, KraftDoc *doc )
             // qDebug () << "loading document with id " << id << endl;
             dbID dbid;
             dbid = id;
-            doc->setDocID( dbid );
+            doc->setDocID(dbid);
 
             doc->setIdent(      q.value( 0 ).toString() );
             doc->setDocType(    q.value( 1 ).toString() );
@@ -311,7 +328,16 @@ void DocumentSaverDB::load( const QString& id, KraftDoc *doc )
             doc->setSalut(      salut );
             doc->setGoodbye(    q.value( 5 ).toString() );
             doc->setDate (      q.value( 6 ).toDate() );
-            doc->setLastModified( q.value( 7 ).toDate() );
+            QDateTime dt = q.value(7).toDateTime();
+
+            // Sqlite stores the timestamp as UTC in the database. Mysql does not.
+            if (KraftDB::self()->isSqlite()) {
+                dt.setTimeSpec(Qt::UTC);
+                doc->setLastModified(dt.toLocalTime());
+            } else {
+                doc->setLastModified(dt);
+            }
+
             // Removed, as with Kraft 0.80 there is no locale management on doc level any more
             // doc->setCountryLanguage( q.value( 8 ).toString(),
             //                         q.value( 9 ).toString());
