@@ -26,12 +26,15 @@
 #include <QDebug>
 #include <QDomDocument>
 #include <QDomElement>
+#include <QTimer>
 
 #include "version.h"
 #include "kraftdb.h"
 #include "doctype.h"
 #include "dbids.h"
 #include "defaultprovider.h"
+#include "archiveman.h"
+#include "documentsaverdb.h"
 
 Q_GLOBAL_STATIC(KraftDB, mSelf)
 
@@ -103,7 +106,10 @@ KraftDB::KraftDB()
     :QObject (), mParent(nullptr),
       mSuccess( true ),
       EuroTag( QString::fromLatin1( "%EURO" ) ),
-      mInitDialog(nullptr)
+      mInitDialog(nullptr),
+      _amountOfDocs(-1),
+      _amountOfArchs(-1),
+      _emitDBChangeSignal(true)
 {
     // Attention: Before setup assistant rewrite, dbConnect() was called here.
     // Keep that in mind, maybe the auto connect to the DB now misses somewhere.
@@ -173,6 +179,14 @@ bool KraftDB::dbConnect( const QString& driver, const QString& dbName,
             mSuccess = false;
         }
     }
+
+    bool detectChanges {true};
+
+    connect( &_timer, &QTimer::timeout, this, &KraftDB::slotCheckDocDatabaseChanged);
+
+    if (mSuccess && detectChanges) {
+        _timer.start(10*1000);
+    }
     return mSuccess;
 }
 
@@ -606,7 +620,7 @@ void KraftDB::writeWordList( const QString& listName, const QStringList& list )
 
 bool KraftDB::checkTableExistsSqlite(const QString& name, const QStringList& lookupCols)
 {
-    const QString query = QLatin1Literal("PRAGMA table_info(")+name+(")");
+    const QString query = QString("PRAGMA table_info(%1)").arg(name);
     QSqlQuery q(query);
     QStringList cols = lookupCols;
 
@@ -628,3 +642,88 @@ KraftDB::~KraftDB()
 {
 }
 
+void KraftDB::slotCheckDocDatabaseChanged()
+{
+    bool changed{false};
+    {
+        QSqlQuery q("SELECT count(*) FROM document");
+
+        q.exec();
+        QSqlError err = q.lastError();
+        if( err.isValid() ) {
+            qDebug() << "Error: " << err.text();
+            return;
+        }
+
+        if ( q.next() ) {
+            bool ok;
+            int cnt = q.value(0).toInt(&ok);
+
+            if (_amountOfDocs != -1 && cnt != _amountOfDocs ) {
+                qDebug() << "Docs from" << _amountOfDocs << "to" << cnt;
+                changed = true;
+            }
+            _amountOfDocs = cnt;
+        }
+    }
+    {
+        QSqlQuery qArch("SELECT count(*) FROM archdoc");
+
+        qArch.exec();
+        QSqlError err = qArch.lastError();
+        if( err.isValid() ) {
+            qDebug() << "Error: " << err.text();
+            return;
+        }
+
+        if ( qArch.next() ) {
+            bool ok;
+            int cnt = qArch.value(0).toInt(&ok);
+
+            if (_amountOfArchs != -1 && cnt != _amountOfArchs) {
+                qDebug() << "Arched docs from" << _amountOfArchs << "to" << cnt;
+                changed = true;
+            }
+            _amountOfArchs = cnt;
+        }
+    }
+    if (changed && _emitDBChangeSignal) emit docDatabaseChanged();
+}
+
+dbID KraftDB::archiveDocument( KraftDoc *docPtr )
+{
+    dbID archID = ArchiveMan::self()->archiveDocument( docPtr );
+
+    if (archID.isOk()) {
+        _emitDBChangeSignal = false; // block sending of the signal
+        slotCheckDocDatabaseChanged();
+        _emitDBChangeSignal = true;
+    }
+
+    return archID;
+}
+
+void KraftDB::loadDocument(const QString& id, KraftDoc *docPtr)
+{
+    DocumentSaverDB loader;
+
+    loader.load(id, docPtr);
+}
+
+bool KraftDB::saveDocument(KraftDoc *docPtr)
+{
+    bool res {false};
+    DocumentSaverDB saver;
+
+    if (docPtr) {
+        res  = saver.saveDocument(docPtr);
+        if (res) {
+            _emitDBChangeSignal = false; // block sending of the signal
+            slotCheckDocDatabaseChanged();
+            _emitDBChangeSignal = true;
+        }
+    }
+
+    return res;
+}
+
