@@ -52,6 +52,9 @@ PositionViewWidget::PositionViewWidget()
   m_sbUnitPrice->setMinimum( -999999.99 );
   m_sbUnitPrice->setMaximum( 999999.99 );
   m_sbUnitPrice->setDecimals( 2 );
+  const QString currSymbol = DefaultProvider::self()->locale()->currencySymbol();
+  m_sbUnitPrice->setSuffix(" " + currSymbol);
+
 
   m_sbAmount->setMinimum( -999999.99 );
   m_sbAmount->setMaximum( 999999.99 );
@@ -154,7 +157,7 @@ PositionViewWidget::PositionViewWidget()
   this->layout()->setMargin( 6 );
 }
 
-void PositionViewWidget::setDocPosition( DocPositionBase *dp, QLocale* loc )
+void PositionViewWidget::setDocPosition( DocPositionBase *dp)
 {
   if( ! dp ) {
     qCritical() << "setDocPosition got empty position!" << endl;
@@ -172,17 +175,17 @@ void PositionViewWidget::setDocPosition( DocPositionBase *dp, QLocale* loc )
   lStatus->hide();
   lKind->hide();
 
-  setLocale( loc );
   AttributeMap amap = dp->attributes();
 
+  QString unit = pos->unit().einheitSingular();
+  m_cbUnit->setCurrentIndex(m_cbUnit->findText( unit ));
+
   if( dp->type() == DocPositionBase::Position ) {
     positionDetailStack->setCurrentWidget( positionPage );
 
     m_sbAmount->blockSignals( true );
     m_sbAmount->setValue( pos->amount() );
     m_sbAmount->blockSignals( false );
-    QString unit = pos->unit().einheitSingular();
-    m_cbUnit->setCurrentIndex(m_cbUnit->findText( unit ));
 
     m_sbUnitPrice->blockSignals( true );
     m_sbUnitPrice->setValue( pos->unitPrice().toDouble() );
@@ -291,14 +294,6 @@ QString PositionViewWidget::extraDiscountTagRestriction()
   return QString();
 }
 
-void PositionViewWidget::setLocale( QLocale *loc )
-{
-  mLocale = loc;
-  const QString currSymbol = mLocale->currencySymbol();
-  m_sbUnitPrice->setSuffix(" " + currSymbol);
-  slotSetOverallPrice( currentPrice() );
-}
-
 void PositionViewWidget::slotTaggingButtonPressed()
 {
   // qDebug () << "opening tagging dialog" << endl;
@@ -536,7 +531,7 @@ void PositionViewWidget::slotSetOverallPrice( Geld g )
   // if ( mPositionPtr->type() == DocPosition::ExtraDiscount ) {
   //   m_sumLabel->setText( "--" );
   // } else {
-    m_sumLabel->setText( g.toString( mLocale ) );
+    m_sumLabel->setText( g.toString() );
     // }
 }
 
